package org.colllib.util;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.math.BigInteger;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;

/**
 * This file is part of CollLib released under the terms of the LGPL V3.0.
 * See the file licenses/lgpl-3.0.txt for details.
 * 
 * @author marcel.billen
 */
public class FileUtil {
   private FileUtil() {}

   /**
    * Calculate the checksum of a file.
    * @param algorithm  The name of the algorithm to be used
    * @param in  The file whose checksum should be calculated
    * @return  The checksum of the file calculated using the given algorithm
    */
   public static String checksum(String algorithm, File in) {
      InputStream is = null;
      try {
         MessageDigest digest = MessageDigest.getInstance(algorithm);
         is = new FileInputStream(in);

         int read = 0;
         byte[] buffer = new byte[16384];
         while((read = is.read(buffer)) > 0)
            digest.update(buffer, 0, read);
         return new BigInteger(1, digest.digest()).toString(16);
      }
      catch(NoSuchAlgorithmException e) {
         throw new RuntimeException(e);
      }
      catch(IOException e) {
         throw new RuntimeException(e);
      }
      finally {
         if(is != null)
            try { is.close(); }
            catch(IOException e) {}
      }      
   }
}

